# Breath of the Wild Enemy Randomizer v2 by Echocolat 

_Big thanks to ArchLeaders for his help and MintLightning for cleaning up the scripts, some help with tweaking, and the arrangement into one file._

### What do you need:
1. BCML _(`pip install bcml`)_ | Setup required.
2. Python 3.7-3.8 (added to PATH)
3. oead _(`pip install oead`)_
4. botw_flag_util _(`pip install botw_flag_util`)_
4. A legally obtained copy of Breath of the Wild v1.5.0 with DLC

### How to use:
1. Download the [source code](https://github.com/Echocolat/EnemyRandomizerComplete/archive/refs/heads/master.zip) and unzip it.
2. Open a cmd/terminal in the root folder and type `python src/main.py`.
3. Follow the prompts and wait for completion.
4. Enjoy **Enemizer**!!
	
_If you need any help, because you don't know how to make the mod working for example, don't hesitate to contact me (@Echocolat#9988 on Discord) 
or to put a comment on the GameBanana page of the mod._